Durations
=========

.. toctree::
   :maxdepth: 0

   introduction/index
   assignability/index
   prolation/index
   types/index
   initialization/index
   leaf_multipliers/index
   interfaces_compared/index

.. rationals/index
.. token/index
